@@ -1,4 +1,5 @@
 package Qt::Core::QReadWriteLock;
+# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
 # classname: QReadWriteLock
 # file     : QtCore/qreadwritelock.h
 
@@ -6,16 +7,11 @@ use strict;
 use warnings;
 #use Carp;
 
-our $VERSION = '0.01_01';
+our $VERSION = '0.01_02';
 
 
 # FIXME: operator overload
 
-# enums
-# enum value in perl is enum item index number
-sub NonRecursive() { 0 }
-sub Recursive() { 1 }
-
 
 1;
 
@@ -27,25 +23,36 @@ Qt::Core::QReadWriteLock
 
 =over
 
-=item    QReadWriteLock()
+=item   QReadWriteLock()
 
-=item    QReadWriteLock(QReadWriteLock::RecursionMode recursionMode)
+=item   QReadWriteLock(QReadWriteLock::RecursionMode recursionMode)
 
-=item    ~QReadWriteLock()
+=item   ~QReadWriteLock()
 
-=item   void lockForRead()
+=item  void lockForRead()
 
-=item   void lockForWrite()
+=item  void lockForWrite()
 
-=item   bool tryLockForRead()
+=item  bool tryLockForRead()
 
-=item   bool tryLockForRead(int timeout)
+=item  bool tryLockForRead(int timeout)
 
-=item   bool tryLockForWrite()
+=item  bool tryLockForWrite()
 
-=item   bool tryLockForWrite(int timeout)
+=item  bool tryLockForWrite(int timeout)
 
-=item   void unlock()
+=item  void unlock()
+
+
+=back
+
+=head1 ENUM VALUES
+
+=over
+
+=item NonRecursive
+
+=item Recursive
 
 
 =back
