@@ -1,4 +1,5 @@
 package Qt::Core::QtConcurrent::UnhandledException;
+# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
 # classname: QtConcurrent::UnhandledException
 # file     : QtCore/qtconcurrentexception.h
 
@@ -6,13 +7,13 @@ use strict;
 use warnings;
 #use Carp;
 
-our $VERSION = '0.01_01';
+our $VERSION = '0.01_02';
+our $ISA     = qw/Qt::Core::QtConcurrent::Exception/;
 
 
 # FIXME: operator overload
 
 
-
 1;
 
 =head1 NAME
@@ -23,9 +24,16 @@ Qt::Core::QtConcurrent::UnhandledException
 
 =over
 
-=item   QtConcurrent::Exception * clone()
+=item  QtConcurrent::Exception * clone()
 
-=item   void raise()
+=item  void raise()
+
+
+=back
+
+=head1 ENUM VALUES
+
+=over
 
 
 =back
